.. Orange3-Associate documentation master file, created by
   sphinx-quickstart on Fri Jun  3 12:00:36 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Orange3-Associate documentation!
===========================================

Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/associationrules
   widgets/frequentitemsets

Scripting
------------

.. toctree::
   :maxdepth: 1

   scripting.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

